@@ -10,7 +10,7 @@ NULL
 #'
 #' Train a Deep Neural Network model using the training data from
 #' \code{\linkS4class{DigitalDLSorter}} object. In addition, the trained model
-#' is evaluated with test data and prediction results are otained to determine
+#' is evaluated with test data and prediction results are computed to determine
 #' its performance (see \code{?\link{calculateEvalMetrics}}). Training and
 #' evaluation can be performed using simulated profiles stored in the
 #' \code{\linkS4class{DigitalDLSorter}} object or 'on the fly' by simulating the
@@ -21,13 +21,12 @@ NULL
 #'
 #' All Deep Learning related steps in the \pkg{digitalDLSorteR} package are
 #' performed by using the \pkg{keras} package, an API in R for \pkg{keras} in
-#' Python available on CRAN. We recommend using the installation guide available
-#' at \url{https://tensorflow.rstudio.com/} in order to set a more customized
-#' configuration.
+#' Python available on CRAN. We recommend using the \code{installTFpython} 
+#' function included in the package. 
 #'
 #' \strong{Simulation of bulk RNA-Seq profiles 'on the fly'}
 #'
-#' \code{trainDigitalDLSorterModel} allows to avoid storing bulk RNA-Seq
+#' \code{trainDDLSModel} allows to avoid storing bulk RNA-Seq
 #' profiles by using \code{on.the.fly} argument. This functionality aims to
 #' avoid exexcution times and memory usage of the \code{simBulkProfiles}
 #' function, as the simulated pseudo-bulk profiles are built in each batch
@@ -35,7 +34,7 @@ NULL
 #'
 #' \strong{Neural network architecture}
 #'
-#' By default, \code{\link{trainDigitalDLSorterModel}} implements the
+#' By default, \code{\link{trainDDLSModel}} implements the
 #' architecture selected in Torroja and Sánchez-Cabo, 2019. However, as the
 #' default architecture may not produce good results depending on the dataset,
 #' it is possible to change its parameters by using the corresponding argument:
@@ -50,9 +49,12 @@ NULL
 #' @param object \code{\linkS4class{DigitalDLSorter}} object with
 #'   \code{single.cell.real}/\code{single.cell.simul}, \code{prob.cell.matrix}
 #'   and \code{bulk.simul} slots.
-#' @param combine Type of profiles to be used for training. Can be
-#'   \code{'both'}, \code{'single-cell'} or \code{'bulk'} (\code{'both'} by
-#'   default). For test data, both types of profiles will be used.
+#' @param type.data.train Type of profiles to be used for training. It can be
+#'   \code{'both'}, \code{'single-cell'} or \code{'bulk'} (\code{'bulk'} by
+#'   default).
+#' @param type.data.test Type of profiles to be used for evaluation. It can be
+#'   \code{'both'}, \code{'single-cell'} or \code{'bulk'} (\code{'bulk'} by
+#'   default).
 #' @param batch.size Number of samples per gradient update. If not specified,
 #'   \code{batch.size} will default to 64.
 #' @param num.epochs Number of epochs to train the model (10 by default).
@@ -78,11 +80,18 @@ NULL
 #'   "categorical_accuracy")} by default). See the
 #'   \href{https://tensorflow.rstudio.com/reference/keras/metric_binary_accuracy.html}{keras
 #'    documentation} to know available performance metrics.
+#' @param normalize Whether to normalize data using logCPM (\code{TRUE} by 
+#'   default). This parameter is only considered when the method used to 
+#'   simulate mixed transcriptional profiles (\code{simMixedProfiles} 
+#'   function) was \code{"AddRawCount"}. Otherwise, data were already 
+#'   normalized.
 #' @param scaling How to scale data before training. It may be:
-#'   \code{"standarize"} (values are centered around the mean with a unit
+#'   \code{"standardize"} (values are centered around the mean with a unit
 #'   standard deviation) or \code{"rescale"} (values are shifted and rescaled so
 #'   that they end up ranging between 0 and 1).
-#' @param custom.model Allows to use a custom neural network. It must be a
+#' @param norm.batch.layers Whether to include batch normalization layers
+#'   between each hidden dense layer (\code{TRUE} by default).
+#' @param custom.model It allows to use a custom neural network. It must be a
 #'   \code{keras.engine.sequential.Sequential} object in which the number of
 #'   input neurons is equal to the number of considered features/genes, and the
 #'   number of output neurons is equal to the number of cell types considered
@@ -91,6 +100,10 @@ NULL
 #' @param shuffle Boolean indicating whether data will be shuffled (\code{TRUE}
 #'   by default). Note that if \code{bulk.simul} is not \code{NULL}, the data
 #'   already has been shuffled and \code{shuffle} will be ignored.
+#' @param use.generator Boolean indicating whether to use generators during
+#'   training and test. Generators are automatically used when \code{on.the.fly
+#'   = TRUE} or HDF5 files are used, but it can be activated by the user on
+#'   demand (\code{FALSE} by default).
 #' @param on.the.fly Boolean indicating whether data will be generated 'on the
 #'   fly' during training (\code{FALSE} by default).
 #' @param pseudobulk.function Function used to build pseudo-bulk samples. It may
@@ -118,7 +131,7 @@ NULL
 #' @export
 #'
 #' @seealso \code{\link{plotTrainingHistory}}
-#'   \code{\link{deconvDigitalDLSorter}} \code{\link{deconvDigitalDLSorterObj}}
+#'   \code{\link{deconvDigitalDLSorter}} \code{\link{deconvDDLSObj}}
 #'
 #' @examples
 #' \dontrun{
@@ -139,10 +152,12 @@ NULL
 #'     Gene_ID = paste0("Gene", seq(15))
 #'   )
 #' )
-#' DDLS <- loadSCProfiles(
-#'   single.cell.data = sce,
-#'   cell.ID.column = "Cell_ID",
-#'   gene.ID.column = "Gene_ID"
+#' DDLS <- createDDLSobject(
+#'   sc.data = sce,
+#'   sc.cell.ID.column = "Cell_ID",
+#'   sc.gene.ID.column = "Gene_ID",
+#'   sc.filt.genes.cluster = FALSE, 
+#'   sc.log.FC = FALSE
 #' )
 #' probMatrixValid <- data.frame(
 #'   Cell_Type = paste0("CellType", seq(2)),
@@ -159,7 +174,7 @@ NULL
 #' )
 #' # training of DDLS model
 #' tensorflow::tf$compat$v1$disable_eager_execution()
-#' DDLS <- trainDigitalDLSorterModel(
+#' DDLS <- trainDDLSModel(
 #'   object = DDLS,
 #'   on.the.fly = TRUE,
 #'   batch.size = 12,
@@ -171,11 +186,12 @@ NULL
 #'   Learning algorithm to quantify immune cell populations based on scRNA-Seq
 #'   data. Frontiers in Genetics 10, 978. doi: \doi{10.3389/fgene.2019.00978}
 #'   
-trainDigitalDLSorterModel <- function(
+trainDDLSModel <- function(
   object,
-  combine = "both",
+  type.data.train = "bulk",
+  type.data.test = "bulk",
   batch.size = 64,
-  num.epochs = 10,
+  num.epochs = 60,
   num.hidden.layers = 2,
   num.units = c(200, 200),
   activation.fun = "relu",
@@ -183,11 +199,14 @@ trainDigitalDLSorterModel <- function(
   loss = "kullback_leibler_divergence",
   metrics = c("accuracy", "mean_absolute_error",
               "categorical_accuracy"),
-  scaling = "standarize",
+  normalize = TRUE,
+  scaling = "standardize",
+  norm.batch.layers = TRUE,
   custom.model = NULL,
-  shuffle = FALSE,
+  shuffle = TRUE,
+  use.generator = FALSE,
   on.the.fly = FALSE,
-  pseudobulk.function = "MeanCPM",
+  pseudobulk.function = "AddRawCount",
   threads = 1,
   view.metrics.plot = TRUE,
   verbose = TRUE
@@ -203,46 +222,53 @@ trainDigitalDLSorterModel <- function(
   } else if (batch.size < 10) {
     stop("'batch.size' argument must be greater than or equal to 10")
   } 
-  if (!any(combine %in% c("both", "bulk", "single-cell"))) {
-    stop("'combine' argument must be one of the following options: 'both', 'bulk' or 'single-cell'")
+  if (!any(type.data.train %in% c("both", "bulk", "single-cell"))) {
+    stop("'type.data.train' argument must be one of the following options: 'both', 'bulk' or 'single-cell'")
+  }
+  if (!any(type.data.test %in% c("both", "bulk", "single-cell"))) {
+    stop("'type.data.test' argument must be one of the following options: 'both', 'bulk' or 'single-cell'")
   }
   # bulk.simul and single-cell.real/simul must be provided, since we evaluate 
   # our model on both type of samples compulsory
   # check if data provided is correct regarding on the fly training
   if (is.null(single.cell.real(object)) && is.null(single.cell.simul(object))) {
     stop("At least one single-cell slot must be provided ('single.cell.real' ", 
-         "or 'single.cell.simul') as trainDigitalDLSorterModel evaluates ", 
+         "or 'single.cell.simul') as trainDDLSModel evaluates ", 
          "DNN model on both types of profiles: bulk and single-cell")
   }
-  if (!scaling %in% c("standarize", "rescale")) {
-    stop("'scaling' argument must be one of the following options: 'standarize', 'rescale'")
+  if (!scaling %in% c("standardize", "rescale")) {
+    stop("'scaling' argument must be one of the following options: 'standardize', 'rescale'")
   } else {
-    if (scaling == "standarize") {
+    if (scaling == "standardize") {
       scaling.fun <- base::scale
     } else if (scaling == "rescale") {
       scaling.fun <- rescale.function
+    } else if (scaling == "none") {
+      scaling.fun <- function(x) return(x)
     }
   }
   if (!on.the.fly) {
-    if (verbose) message("=== Training and test from stored data was selected")
-    if ((combine == "both" && is.null(bulk.simul(object)) ||
-         combine == "both" && (is.null(single.cell.real(object)) && 
-                               is.null(single.cell.simul(object))))) {
-      stop("If 'combine = both' is selected, 'bulk.simul' and at least ",
-           "one single cell slot must be provided")
-    } else if (combine == "bulk" && is.null(bulk.simul(object))) {
-      stop("If 'combine' = bulk is selected, 'bulk.simul' must be provided")
-    } else if (is.null(bulk.simul(object, "test"))) {
-      stop("trainDigitalDLSorterModel evaluates DNN model on both types of ", 
-           "profiles: bulk and single-cell. Therefore, bulk data for test ", 
-           "must be provided")
-    }
-    .pseudobulk.fun <- NULL
+    vec.type.data <- c(type.data.train, type.data.test)
+    for (type in seq_along(vec.type.data)) {
+      if (verbose & type == 1) message("=== Training and test from stored data")
+      text.message <- ifelse(type == 1, "train" , "test")
+      if (
+        (vec.type.data[type] == "both" && 
+         is.null(bulk.simul(object, type.data = text.message)) ||
+         vec.type.data[type] == "both" && 
+         (is.null(single.cell.real(object)) && is.null(single.cell.simul(object))))
+      ) {
+        stop("If `type.data.", text.message, "` = 'both' is selected, 'bulk.simul' and at least ",
+             "one single cell slot must be provided")
+      } else if (vec.type.data[type] == "mixed" && is.null(bulk.simul(object, type.data = text.message))) {
+        stop("If `type.data.", text.message, "` = 'mixed' is selected, 'bulk.simul' must be provided")
+      } 
+    }  
   } else {
     if (verbose) message("=== Training and test on the fly was selected")
-    if (combine == "both" && (is.null(single.cell.real(object)) && 
-                               is.null(single.cell.simul(object)))) {
-      stop("If 'combine = both' is selected, at least ",
+    if ((type.data.train == "both" | type.data.train == "single-cell") && 
+        (is.null(single.cell.real(object)) && is.null(single.cell.simul(object)))) {
+      stop("If `type.data.train` = 'both' is selected, at least ",
            "one single cell slot must be provided")
     }
     ## just in case of on.the.fly = TRUE
@@ -258,15 +284,9 @@ trainDigitalDLSorterModel <- function(
       }
     }
   }
-  # single-cell must e provided independently of on.the.fly
-  if (combine == "single-cell" && (is.null(single.cell.real(object)) && 
-                                   is.null(single.cell.simul(object)))) {
-    stop("If combine = 'single-cell' is selected, at least ",
-         "one single cell slot must be provided")
-  }
   if (!is.null(trained.model(object))) {
     warning("'trained.model' slot is not empty. So far, digitalDLSorteR",
-            " does not support for multiple trained models, so the current model",
+            " does not support multiple trained models, so the current model",
             " will be overwritten\n",
             call. = FALSE, immediate. = TRUE)
   }
@@ -276,12 +296,12 @@ trainDigitalDLSorterModel <- function(
   if (verbose) verbose.model <- 1
   else verbose.model <- 0
   prob.matrix.train <- .targetForDNN(
-    object = object, combine = combine, 
+    object = object, combine = type.data.train, 
     shuffle = TRUE, type.data = "train", 
     fly = on.the.fly, verbose = verbose
   )
   prob.matrix.test <- .targetForDNN(
-    object = object, combine = "both", 
+    object = object, combine = type.data.test, 
     shuffle = FALSE, type.data = "test", 
     fly = on.the.fly, verbose = verbose
   )
@@ -323,19 +343,33 @@ trainDigitalDLSorterModel <- function(
           name = paste0("Dense", i)
         )
       }
-      model <- model %>% 
-        layer_batch_normalization(name = paste0("BatchNormalization", i)) %>%
-        layer_activation(activation = activation.fun, 
-                         name = paste0("ActivationReLu", i)) %>%
-        layer_dropout(rate = dropout.rate, name = paste0("Dropout", i))
+      if (norm.batch.layers) {
+        model <- model %>% 
+          layer_batch_normalization(name = paste0("BatchNormalization", i)) %>%
+          layer_activation(activation = activation.fun, 
+                           name = paste0("Activation", i)) %>%
+          layer_dropout(rate = dropout.rate, name = paste0("Dropout", i))  
+      } else {
+        model <- model %>% 
+          layer_activation(activation = activation.fun, 
+                           name = paste0("Activation", i)) %>%
+          layer_dropout(rate = dropout.rate, name = paste0("Dropout", i))  
+      }
     }
     # final layer --> compression and proportions
-    model <- model %>% layer_dense(
-      units = ncol(prob.cell.types(object, "train") %>% prob.matrix()),
-      name = paste0("Dense", i + 1)
-    ) %>% layer_batch_normalization(
-      name = paste0("BatchNormalization", i + 1)
-    ) %>% layer_activation(activation = "softmax", name = "ActivationSoftmax")
+    if (norm.batch.layers) {
+      model <- model %>% layer_dense(
+        units = ncol(prob.cell.types(object, "train") %>% prob.matrix()),
+        name = paste0("Dense", i + 1)
+      ) %>% 
+        layer_batch_normalization(name = paste0("BatchNormalization", i + 1)) %>%
+        layer_activation(activation = "softmax", name = "ActivationSoftmax")  
+    } else {
+      model <- model %>% layer_dense(
+        units = ncol(prob.cell.types(object, "train") %>% prob.matrix()),
+        name = paste0("Dense", i + 1)
+      ) %>% layer_activation(activation = "softmax", name = "ActivationSoftmax")  
+    }
   } else {
     # consider more situations where the function fails
     if (!is(custom.model, "keras.engine.sequential.Sequential")) {
@@ -375,80 +409,171 @@ trainDigitalDLSorterModel <- function(
   # set if samples will be generated on the fly
   if (!on.the.fly) {
     .dataForDNN <- .dataForDNN.file
+    if (type.data.train == "bulk") {
+      checkingClass <- is(
+        assay(bulk.simul(object, type.data = "train")), "HDF5Array"
+      )  
+    } else if (type.data.train == "single-cell") {
+      checkingClass <- is(assay(single.cell.real(object)), "HDF5Array")  
+    } else {
+      checkingClass <- all(
+        is(assay(bulk.simul(object, type.data = "train")), "HDF5Array"), 
+        is(assay(single.cell.real(object)), "HDF5Array")
+      )
+    }
   } else {
     .dataForDNN <- .dataForDNN.onFly
+    checkingClass <- FALSE
   }
+  
   if (verbose) 
     message(paste("\n=== Training DNN with", n.train, "samples:\n"))
-  gen.train <- .trainGenerator(
-    object = object, 
-    funGen = .dataForDNN,
-    prob.matrix = prob.matrix.train,
-    type.data = "train",
-    fun.pseudobulk = .pseudobulk.fun,
-    scaling = scaling.fun,
-    batch.size = batch.size,
-    combine = combine,
-    shuffle = shuffle,
-    pattern = pattern,
-    min.index = NULL,
-    max.index = NULL,
-    threads = threads,
-    verbose = verbose
-  )
-  history <- model %>% fit_generator(
-    generator = gen.train,
-    steps_per_epoch = ceiling(n.train / batch.size),
-    epochs = num.epochs,
-    verbose = verbose.model,
-    view_metrics = view.plot
-  )
-  # }
-  if (verbose)
-    message(paste0("\n=== Evaluating DNN in test data (", n.test, " samples)"))
+  
+  if (use.generator | isTRUE(on.the.fly) | checkingClass) {
+    gen.train <- .trainGenerator(
+      object = object, 
+      funGen = .dataForDNN,
+      prob.matrix = prob.matrix.train,
+      type.data = "train",
+      mixing.fun = ifelse(
+        any(type.data.train %in% c("bulk", "both")) & on.the.fly == FALSE,
+        yes = bulk.simul(object, "train")@metadata[["mixing.fun"]],
+        no = pseudobulk.function
+      ),
+      fun.pseudobulk = .pseudobulk.fun,
+      scaling = scaling.fun,
+      batch.size = batch.size,
+      combine = type.data.train,
+      shuffle = shuffle,
+      pattern = pattern,
+      min.index = NULL,
+      max.index = NULL,
+      threads = threads,
+      verbose = verbose
+    )
+    history <- model %>% fit_generator(
+      generator = gen.train,
+      steps_per_epoch = ceiling(n.train / batch.size),
+      epochs = num.epochs,
+      verbose = verbose.model,
+      view_metrics = view.plot
+    )
+    # }
+    if (verbose)
+      message(paste0("\n=== Evaluating DNN in test data (", n.test, " samples)"))
 
-  # evaluation of the model: set by default, no options?
-  gen.test <- .predictGenerator(
-    object,
-    funGen = .dataForDNN,
-    target = TRUE,
-    prob.matrix = prob.matrix.test,
-    fun.pseudobulk = .pseudobulk.fun,
-    scaling = scaling.fun,
-    batch.size = batch.size,
-    pattern = pattern,
-    threads = threads,
-    verbose = verbose
-  )
-  test.eval <- model %>% evaluate_generator(
-    generator = gen.test,
-    steps = ceiling(n.test / batch.size)
-  )
-  # prediction of test samples
-  if (verbose) {
-    message(paste0("   - ", names(test.eval), ": ", lapply(test.eval, round, 4),
-                   collapse = "\n"))
-    message(paste("\n=== Generating prediction results using test data\n"))
+    # evaluation of the model: set by default, no options?
+    gen.test <- .predictGenerator(
+      object,
+      funGen = .dataForDNN,
+      target = TRUE,
+      prob.matrix = prob.matrix.test,
+      mixing.fun = ifelse(
+        any(type.data.train %in% c("bulk", "both")) & on.the.fly == FALSE,
+        yes = bulk.simul(object, "test")@metadata[["mixing.fun"]],
+        no = pseudobulk.function
+      ),
+      fun.pseudobulk = .pseudobulk.fun,
+      scaling = scaling.fun,
+      batch.size = batch.size,
+      pattern = pattern,
+      threads = threads,
+      verbose = verbose
+    )
+    test.eval <- model %>% evaluate_generator(
+      generator = gen.test,
+      steps = ceiling(n.test / batch.size)
+    )
+    # prediction of test samples
+    if (verbose) {
+      message(paste0("   - ", names(test.eval), ": ", lapply(test.eval, round, 4),
+                     collapse = "\n"))
+      message(paste("\n=== Generating prediction results using test data\n"))
+    }
+    gen.predict <- .predictGenerator(
+      object,
+      funGen = .dataForDNN,
+      target = FALSE,
+      prob.matrix = prob.matrix.test,
+      mixing.fun = ifelse(
+        any(type.data.train %in% c("bulk", "both")) & on.the.fly == FALSE,
+        yes = bulk.simul(object, "test")@metadata[["mixing.fun"]],
+        no = pseudobulk.function
+      ),
+      fun.pseudobulk = .pseudobulk.fun,
+      scaling = scaling.fun,
+      batch.size = batch.size,
+      pattern = pattern,
+      threads = threads,
+      verbose = verbose
+    )
+    predict.results <- model %>% predict_generator(
+      generator = gen.predict,
+      steps = ceiling(n.test / batch.size),
+      verbose = verbose.model
+    )
+    rownames(predict.results) <- rownames(prob.matrix.test)
+    colnames(predict.results) <- colnames(prob.matrix.test)
+  } else { # no generators, everything is loaded into memory
+    dataTrain <- .dataForDNN.file(
+      object = object,
+      sel.data = prob.matrix.train,
+      pattern = pattern,
+      type.data = "train",
+      mixing.fun = ifelse(
+        any(type.data.train %in% c("mixed", "both")) & on.the.fly == FALSE,
+        yes = bulk.simul(object, "train")@metadata[["mixing.fun"]],
+        no = pseudobulk.function
+      ),
+      fun.pseudobulk = .pseudobulk.fun,
+      normalize = normalize,
+      scaling = scaling.fun,
+      threads = threads
+    )
+    history <- model %>% fit(
+      dataTrain,
+      prob.matrix.train,
+      epochs = num.epochs,
+      batch_size = batch.size,
+      verbose = verbose.model,
+      view_metrics = view.plot
+    )
+    if (verbose)
+      message(paste0("\n=== Evaluating DNN in test data (", n.test, " samples)"))
+    
+    # evaluation of the model
+    dataTest <- .dataForDNN.file(
+      object = object,
+      sel.data = prob.matrix.test,
+      pattern = pattern,
+      type.data = "test",
+      mixing.fun = ifelse(
+        any(type.data.test %in% c("mixed", "both")) & on.the.fly == FALSE,
+        yes = bulk.simul(object, "test")@metadata[["mixing.fun"]],
+        no = pseudobulk.function
+      ),
+      fun.pseudobulk = .pseudobulk.fun,
+      normalize = normalize,
+      scaling = scaling.fun,
+      threads = threads
+    )
+    test.eval <- model %>% evaluate(
+      dataTest,
+      prob.matrix.test
+    )
+    # prediction of test samples
+    if (verbose) {
+      message(paste0("   - ", names(test.eval), ": ", lapply(test.eval, round, 4),
+                     collapse = "\n"))
+      message(paste("\n=== Generating prediction results using test data\n"))
+    }
+    predict.results <- model %>% predict(
+      dataTest,
+      verbose = verbose.model
+    )
+    rownames(predict.results) <- rownames(prob.matrix.test)
+    colnames(predict.results) <- colnames(prob.matrix.test)  
   }
-  gen.predict <- .predictGenerator(
-    object,
-    funGen = .dataForDNN,
-    target = FALSE,
-    prob.matrix = prob.matrix.test,
-    fun.pseudobulk = .pseudobulk.fun,
-    scaling = scaling.fun,
-    batch.size = batch.size,
-    pattern = pattern,
-    threads = threads,
-    verbose = verbose
-  )
-  predict.results <- model %>% predict_generator(
-    generator = gen.predict,
-    steps = ceiling(n.test / batch.size),
-    verbose = verbose.model
-  )
-  rownames(predict.results) <- rownames(prob.matrix.test)
-  colnames(predict.results) <- colnames(prob.matrix.test)
   
   network.object <- new(
     Class = "DigitalDLSorterDNN",
@@ -469,7 +594,9 @@ trainDigitalDLSorterModel <- function(
   funGen,
   prob.matrix,
   type.data,
+  mixing.fun,
   fun.pseudobulk,
+  normalize,
   scaling,
   batch.size,
   combine,
@@ -506,7 +633,9 @@ trainDigitalDLSorterModel <- function(
         sel.data = sel.data, 
         pattern = pattern,
         type.data = type.data,
+        mixing.fun = mixing.fun,
         fun.pseudobulk = fun.pseudobulk,
+        normalize = normalize,
         scaling = scaling,
         threads = threads
       )
@@ -521,7 +650,9 @@ trainDigitalDLSorterModel <- function(
         sel.data = sel.data, 
         pattern = pattern,
         type.data = type.data,
+        mixing.fun = mixing.fun,
         fun.pseudobulk = fun.pseudobulk,
+        normalize = normalize,
         scaling = scaling,
         threads = threads
       )
@@ -537,7 +668,9 @@ trainDigitalDLSorterModel <- function(
   funGen,
   prob.matrix,
   target,
+  mixing.fun,
   fun.pseudobulk,
+  normalize,
   scaling,
   batch.size,
   pattern,
@@ -559,7 +692,9 @@ trainDigitalDLSorterModel <- function(
       sel.data = sel.data, 
       pattern = pattern,
       type.data = "test",
+      mixing.fun = mixing.fun,
       fun.pseudobulk = fun.pseudobulk,
+      normalize = normalize,
       scaling = scaling,
       threads = threads
     )
@@ -573,7 +708,9 @@ trainDigitalDLSorterModel <- function(
   sel.data,
   pattern,
   type.data,
+  mixing.fun,
   fun.pseudobulk,
+  normalize,
   scaling,
   threads
 ) {
@@ -613,15 +750,21 @@ trainDigitalDLSorterModel <- function(
   # return final matrix counts
   if (any(bulk.data) && any(!bulk.data)) {
     cell.samples <- log2(.cpmCalculate(x = cell.samples + 1))
+    if (normalize & mixing.fun == "AddRawCount") {
+      bulk.samples <- log2(.cpmCalculate(x = bulk.samples + 1))
+    }
     counts <- cbind(bulk.samples, cell.samples)[, rownames(sel.data), drop = FALSE]
   } else if (any(bulk.data)) {
+    if (normalize & mixing.fun == "AddRawCount") {
+      bulk.samples <- log2(.cpmCalculate(x = bulk.samples + 1))
+    }
     counts <- bulk.samples[, rownames(sel.data), drop = FALSE]
   } else if (any(!bulk.data)) {
     counts <- log2(
       .cpmCalculate(x = cell.samples[, rownames(sel.data), drop = FALSE] + 1)
     )
   }
-  return(t(scaling(counts)))
+  return(scaling(t(counts)))
 }
 
 .dataForDNN.onFly <- function(
@@ -629,7 +772,9 @@ trainDigitalDLSorterModel <- function(
   sel.data,
   pattern,
   type.data,
+  mixing.fun,
   fun.pseudobulk,
+  normalize,
   scaling,
   threads
 ) {
@@ -675,15 +820,21 @@ trainDigitalDLSorterModel <- function(
   # return final matrix counts
   if (any(bulk.data) && any(!bulk.data)) {
     cell.samples <- log2(.cpmCalculate(x = cell.samples + 1))
+    if (normalize & mixing.fun == "AddRawCount") {
+      bulk.samples <- log2(.cpmCalculate(x = bulk.samples + 1))
+    }
     counts <- cbind(bulk.samples, cell.samples)[, rownames(sel.data), drop = FALSE]
   } else if (any(bulk.data)) {
+    if (normalize & mixing.fun == "AddRawCount") {
+      bulk.samples <- log2(.cpmCalculate(x = bulk.samples + 1))
+    }
     counts <- bulk.samples[, rownames(sel.data), drop = FALSE]
   } else if (any(!bulk.data)) {
     counts <- log2(
       .cpmCalculate(x = cell.samples[, rownames(sel.data), drop = FALSE] + 1)
     )
   }
-  return(t(scaling(counts)))
+  return(scaling(t(counts)))
 }
 
 .targetForDNN <- function(
@@ -930,7 +1081,7 @@ trainDigitalDLSorterModel <- function(
 #'This function is intended for users who want to use \pkg{digitalDLSorteR} to
 #'deconvolute their bulk RNA-Seq samples using pre-trained models. For users who
 #'want to build their own models from other scRNA-Seq datasets, see the
-#'\code{\link{loadSCProfiles}} and \code{\link{deconvDigitalDLSorterObj}}
+#'\code{\link{createDDLSobject}} and \code{\link{deconvDDLSObj}}
 #'functions.
 #'
 #'@param data Matrix or data frame with bulk RNA-Seq samples with genes as rows
@@ -941,12 +1092,9 @@ trainDigitalDLSorterModel <- function(
 #'  colorectal cancer (\code{colorectal.li}). These pre-trained models are
 #'  stored in the \pkg{digitalDLSorteRdata} package, so it must be installed
 #'  together with \pkg{digitalDLSorteR} to use this function.
-#'@param batch.size Number of samples loaded into RAM each time during the
-#'  deconvolution process. If not specified, \code{batch.size} will be set to
-#'  128.
 #'@param normalize Normalize data before deconvolution (\code{TRUE} by default).
 #'@param scaling How to scale data before training. It may be:
-#'  \code{"standarize"} (values are centered around the mean with a unit
+#'  \code{"standardize"} (values are centered around the mean with a unit
 #'  standard deviation) or \code{"rescale"} (values are shifted and rescaled so
 #'  that they end up ranging between 0 and 1). If \code{normalize = FALSE}, data
 #'  is not scaled.
@@ -957,6 +1105,10 @@ trainDigitalDLSorterModel <- function(
 #'  into the cell type with the highest proportion in each sample. Unlike
 #'  \code{simplify.set}, this argument allows to maintain the complexity of the
 #'  results while compressing the information, as no new labels are created.
+#' @param use.generator Boolean indicating whether to use generators for
+#'   prediction (\code{FALSE} by default).
+#' @param batch.size Number of samples per batch. Only when \code{use.generator
+#'   = TRUE}.
 #'@param verbose Show informative messages during execution.
 #'
 #'@return A data frame with samples (\eqn{i}) as rows and cell types (\eqn{j})
@@ -965,7 +1117,7 @@ trainDigitalDLSorterModel <- function(
 #'
 #'@export
 #'
-#'@seealso \code{\link{deconvDigitalDLSorterObj}}
+#'@seealso \code{\link{deconvDDLSObj}}
 #'
 #' @examples
 #' \dontrun{
@@ -986,10 +1138,12 @@ trainDigitalDLSorterModel <- function(
 #'     Gene_ID = paste0("Gene", seq(15))
 #'   )
 #' )
-#' DDLS <- loadSCProfiles(
-#'   single.cell.data = sce,
-#'   cell.ID.column = "Cell_ID",
-#'   gene.ID.column = "Gene_ID"
+#' DDLS <- createDDLSobject(
+#'   sc.data = sce,
+#'   sc.cell.ID.column = "Cell_ID",
+#'   sc.gene.ID.column = "Gene_ID",
+#'   sc.filt.genes.cluster = FALSE, 
+#'   sc.log.FC = FALSE
 #' )
 #' probMatrixValid <- data.frame(
 #'   Cell_Type = paste0("CellType", seq(6)),
@@ -1006,7 +1160,7 @@ trainDigitalDLSorterModel <- function(
 #' )
 #' # training of DDLS model
 #' tensorflow::tf$compat$v1$disable_eager_execution()
-#' DDLS <- trainDigitalDLSorterModel(
+#' DDLS <- trainDDLSModel(
 #'   object = DDLS,
 #'   on.the.fly = TRUE,
 #'   batch.size = 15,
@@ -1052,11 +1206,12 @@ trainDigitalDLSorterModel <- function(
 deconvDigitalDLSorter <- function(
   data,
   model = NULL,
-  batch.size = 128,
   normalize = TRUE,
-  scaling = "standarize",
+  scaling = "standardize",
   simplify.set = NULL,
   simplify.majority = NULL,
+  use.generator = FALSE,
+  batch.size = 64,
   verbose = TRUE
 ) {
   # check if python dependencies are covered
@@ -1073,10 +1228,10 @@ deconvDigitalDLSorter <- function(
       stop("'model' is not an object of DigitalDLSorterDNN class. Please ",
            "see available models in digitalDLSorteRdata package and ?deconvDigitalDLSorter")
   }
-  if (!scaling %in% c("standarize", "rescaling")) {
-    stop("'scaling' argument must be one of the following options: 'standarize', 'rescaling'")
+  if (!scaling %in% c("standardize", "rescaling")) {
+    stop("'scaling' argument must be one of the following options: 'standardize', 'rescaling'")
   } else {
-    if (scaling == "standarize") {
+    if (scaling == "standardize") {
       scaling.fun <- base::scale
     } else if (scaling == "rescaling") {
       scaling.fun <- rescale.function
@@ -1093,6 +1248,7 @@ deconvDigitalDLSorter <- function(
     batch.size = batch.size,
     normalize = normalize,
     scaling = scaling.fun,
+    use.generator = use.generator,
     verbose = verbose
   )
   if (!is.null(simplify.set) && !is.null(simplify.majority)) {
@@ -1139,12 +1295,10 @@ deconvDigitalDLSorter <- function(
 #'   \code{trained.data} and \code{deconv.data} slots.
 #' @param name.data Name of the data stored in the \code{DigitalDLSorter}
 #'   object. If not provided, the first data set will be used.
-#' @param batch.size Number of samples per gradient update. If not specified,
-#'   \code{batch.size} will default to 128.
 #' @param normalize Normalize data before deconvolution (\code{TRUE} by
 #'   default).
 #' @param scaling How to scale data before training. It may be:
-#'   \code{"standarize"} (values are centered around the mean with a unit
+#'   \code{"standardize"} (values are centered around the mean with a unit
 #'   standard deviation) or \code{"rescale"} (values are shifted and rescaled so
 #'   that they end up ranging between 0 and 1). If \code{normalize = FALSE},
 #'   data is not scaled.
@@ -1158,6 +1312,10 @@ deconvDigitalDLSorter <- function(
 #'   results while compressing the information, as no new labels are created. If
 #'   provided, the results are stored in a list with 'raw' and 'simpli.majority'
 #'   results.
+#' @param use.generator Boolean indicating whether to use generators for
+#'   prediction (\code{FALSE} by default).
+#' @param batch.size Number of samples per batch. Only when \code{use.generator
+#'   = TRUE}.
 #' @param verbose Show informative messages during the execution.
 #'
 #' @return \code{\linkS4class{DigitalDLSorter}} object with
@@ -1170,7 +1328,7 @@ deconvDigitalDLSorter <- function(
 #'
 #' @export
 #'
-#' @seealso \code{\link{trainDigitalDLSorterModel}}
+#' @seealso \code{\link{trainDDLSModel}}
 #'   \code{\linkS4class{DigitalDLSorter}}
 #'
 #' @examples
@@ -1192,10 +1350,12 @@ deconvDigitalDLSorter <- function(
 #'     Gene_ID = paste0("Gene", seq(15))
 #'   )
 #' )
-#' DDLS <- loadSCProfiles(
-#'   single.cell.data = sce,
-#'   cell.ID.column = "Cell_ID",
-#'   gene.ID.column = "Gene_ID"
+#' DDLS <- createDDLSobject(
+#'   sc.data = sce,
+#'   sc.cell.ID.column = "Cell_ID",
+#'   sc.gene.ID.column = "Gene_ID",
+#'   sc.filt.genes.cluster = FALSE, 
+#'   sc.log.FC = FALSE
 #' )
 #' probMatrixValid <- data.frame(
 #'   Cell_Type = paste0("CellType", seq(6)),
@@ -1212,7 +1372,7 @@ deconvDigitalDLSorter <- function(
 #' )
 #' # training of DDLS model
 #' tensorflow::tf$compat$v1$disable_eager_execution()
-#' DDLS <- trainDigitalDLSorterModel(
+#' DDLS <- trainDDLSModel(
 #'   object = DDLS,
 #'   on.the.fly = TRUE,
 #'   batch.size = 15,
@@ -1233,7 +1393,7 @@ deconvDigitalDLSorter <- function(
 #' # simplify arguments
 #' simplify <- list(CellGroup1 = c("CellType1", "CellType2", "CellType4"),
 #'                  CellGroup2 = c("CellType3", "CellType5"))
-#' DDLS <- deconvDigitalDLSorterObj(
+#' DDLS <- deconvDDLSObj(
 #'   object = DDLS,
 #'   name.data = "Example",
 #'   simplify.set = simplify,
@@ -1244,14 +1404,15 @@ deconvDigitalDLSorter <- function(
 #'   Learning algorithm to quantify immune cell populations based on scRNA-Seq
 #'   data. Frontiers in Genetics 10, 978. doi: \doi{10.3389/fgene.2019.00978}
 #'   
-deconvDigitalDLSorterObj <- function(
+deconvDDLSObj <- function(
   object,
-  name.data,
-  batch.size = 128,
+  name.data = "Bulk.DT",
   normalize = TRUE,
-  scaling = "standarize",
+  scaling = "standardize",
   simplify.set = NULL,
   simplify.majority = NULL,
+  use.generator = FALSE,
+  batch.size = 64,
   verbose = TRUE
 ) {
   # check if python dependencies are covered
@@ -1263,10 +1424,10 @@ deconvDigitalDLSorterObj <- function(
   } else if (!name.data %in% names(deconv.data(object))) {
     stop("'name.data' provided is not present in DigitalDLSorter object")
   }
-  if (!scaling %in% c("standarize", "rescaling")) {
-    stop("'scaling' argument must be one of the following options: 'standarize', 'rescaling'")
+  if (!scaling %in% c("standardize", "rescaling")) {
+    stop("'scaling' argument must be one of the following options: 'standardize', 'rescaling'")
   } else {
-    if (scaling == "standarize") {
+    if (scaling == "standardize") {
       scaling.fun <- base::scale
     } else if (scaling == "rescaling") {
       scaling.fun <- rescale.function
@@ -1289,6 +1450,7 @@ deconvDigitalDLSorterObj <- function(
     batch.size = batch.size,
     normalize = normalize,
     scaling = scaling.fun,
+    use.generator = use.generator,
     verbose = verbose
   )
 
@@ -1329,6 +1491,7 @@ deconvDigitalDLSorterObj <- function(
   batch.size,
   normalize,
   scaling,
+  use.generator,
   verbose
 ) {
   if (is.null(rownames(deconv.counts))) {
@@ -1341,10 +1504,12 @@ deconvDigitalDLSorterObj <- function(
   deconv.counts <- deconv.counts[filter.features, ]
   # set features missing in deconv.data
   fill.features <- !features(model) %in% rownames(deconv.counts)
-  m.new <- matrix(0L, nrow = sum(fill.features), ncol = ncol(deconv.counts))
-  rownames(m.new) <- features(model)[fill.features]
-  deconv.counts <- rbind(deconv.counts, m.new)
-  deconv.counts <- deconv.counts[features(model), ]
+  if (any(fill.features)) {
+    m.new <- matrix(0L, nrow = sum(fill.features), ncol = ncol(deconv.counts))
+    rownames(m.new) <- features(model)[fill.features]
+    deconv.counts <- rbind(deconv.counts, m.new)
+    deconv.counts <- deconv.counts[features(model), ]  
+  }
   if (verbose) {
     message(paste("=== Filtering", sum(!filter.features),
                   "features in data that are not present in trained model\n"))
@@ -1354,9 +1519,13 @@ deconvDigitalDLSorterObj <- function(
   if (normalize) {
     if (verbose) message("=== Normalizing and scaling data\n")
     deconv.counts <- log2(.cpmCalculate(x = deconv.counts + 1))
-    deconv.counts <- scaling(deconv.counts)
+    deconv.counts <- scaling(t(deconv.counts))
+  } else {
+    deconv.counts <- as.matrix(deconv.counts)
+    deconv.counts <- scaling(t(deconv.counts))
   }
-  deconv.counts <- t(deconv.counts)
+  # deconv.counts <- t(deconv.counts)
+  
   deconv.generator <- .predictDeconvDataGenerator(
     data = deconv.counts,
     model = model,
@@ -1369,11 +1538,23 @@ deconvDigitalDLSorterObj <- function(
     verbose.model <- 0
   }
   dnn.model <- model(model)
-  results <- dnn.model %>% predict_generator(
-    generator = deconv.generator,
-    steps = ceiling(nrow(deconv.counts) / batch.size),
-    verbose = verbose.model
-  )
+  if (use.generator) {
+    deconv.generator <- .predictDeconvDataGenerator(
+      data = deconv.counts,
+      model = model,
+      batch.size = batch.size
+    )
+    results <- dnn.model %>% predict_generator(
+      generator = deconv.generator,
+      steps = ceiling(nrow(deconv.counts) / batch.size),
+      verbose = verbose.model
+    )  
+  } else {
+    results <- dnn.model %>% predict(
+      deconv.counts,
+      verbose = verbose.model
+    )  
+  }
   if (!is.null(rownames(deconv.counts))) {
     rownames.deconv <- rownames(deconv.counts)
   } else {
